@@ -1,5 +1,5 @@
 # UMLS::Similarity::ErrorHandler
-# (Last Updated $Id: ErrorHandler.pm,v 1.7 2010/10/11 22:20:46 btmcinnes Exp $)
+# (Last Updated $Id: ErrorHandler.pm,v 1.8 2010/12/21 16:58:40 btmcinnes Exp $)
 #
 # Perl module that provides a perl interface to the
 # Unified Medical Language System (UMLS)
@@ -79,12 +79,12 @@ sub checkConfig {
     my $measure   = shift;
     my $interface = shift;
 
-    if($measure=~/(path|cdist|nam|wup|lch|jcn|lin|res)/) {
-    	$self->checkPathBasedMeasures($measure, $interface);
-    }
-    elsif($measure=~/(vector|lesk)/ ) {
-    	$self->checkRelatednessMeasures($measure, $interface);
-    }
+    #if($measure=~/(path|cdist|nam|wup|lch|jcn|lin|res)/) {
+    #	$self->checkPathBasedMeasures($measure, $interface);
+    #}
+    #elsif($measure=~/(vector|lesk)/ ) {
+    # 	$self->checkRelatednessMeasures($measure, $interface);
+    #}
 }
 
 #  check the config file with the path-based and IC measures
