@@ -864,7 +864,9 @@ the EACL 2006 Workshop Making Sense of Sense - Bringing Computational
 Linguistics and Psycholinguistics Together, pp. 1-8, April 4, 2006, Trento, Italy.
 http://www.d.umn.edu/~tpederse/Pubs/eacl2006-vector.pdf
 
---indexfile and --matrixfile option. The co-occurrence matrix and index
+--indexfile and --matrixfile option 
+
+The co-occurrence matrix and index
 file used in the vector method are prepared by vector-input.pl method. 
 Index file assigns each term of the bigrams a number and also records the 
 vector position and length which starts the term of the co-occurrence matrix. 
@@ -918,11 +920,15 @@ vector-input.pl requires the bigrams are sorted, and you could use
 count2huge.pl method of Text-NSP to convert the output of count.pl 
 to huge-count.pl. 
 
---defraw option is a flag for the vector measure. The definitions 
+--defraw option 
+
+This is a flag for the vector measure. The definitions 
 used are 'cleaned'. If the --defraw flag is set they will not be cleaned, 
 and it will leave the definitions in their "raw" form. 
 
---dictfile option is a dictionary file for the vector measure. It 
+--dictfile option 
+
+This is a dictionary file for the vector measure. It 
 contains the 'definitions' of a concept which would be used in the 
 relatedness computation. When this option is set, for the input 
 pair, umls-similarity.pl first find the CUIs or terms definition in 
@@ -934,46 +940,50 @@ If the --dictfile option is not set, the definiton will only come from the UMLS
 defintion by the --config option. 
 
 The input pair could be the following formats.
-1. cui1/term1 cui2/term2 
-   without --dictfile option and without --config option, 
-   use the UMLS definition of the default config file. 
 
-2. cui1/term1 cui2/term2  --dictfile ./sample/dictfile
-   --dictfile option is set and without --config option, 
-   definitions only come from dictfile. 
+    1. cui1/term1 cui2/term2 
+       without --dictfile option and without --config option, 
+       use the UMLS definition of the default config file. 
 
-3. cui1/term1 cui2/term2  --config ./sample/leskmeasure.config
-   without --dictfile option, --config option is set, 
-   definitions only come from UMLS by the config file. 
+    2. cui1/term1 cui2/term2  --dictfile ./sample/dictfile
+       --dictfile option is set and without --config option, 
+       definitions only come from dictfile. 
 
-4. cui1/term1 cui2/term2  --dictfile ./sample/dictfile --config ./sample/leskmeasure.config
-   --dictfile option is set, --config option is set, 
-   definitions come from dictfile and UMLS, if the associated term 
-   for each CUI is defined in the dictfile, the associated terms' 
-   definition are also included.  
+    3. cui1/term1 cui2/term2  --config ./sample/leskmeasure.config
+       without --dictfile option, --config option is set, 
+       definitions only come from UMLS by the config file. 
+
+    4. cui1/term1 cui2/term2  --dictfile ./sample/dictfile --config ./sample/leskmeasure.config
+       --dictfile option is set, --config option is set, 
+       definitions come from dictfile and UMLS. If the associated term 
+       for each CUI is defined in the dictfile, the associated terms' 
+       definition are also included.  
 
 Terms in the dictionary file use the delimiter : to seperate the terms and
 their definition. It allows multi terms in one concept. Please see the sample 
 file at /sample/dictfile.  
 
---doubledef option is a dictionary file for the vector measure. It contains the 
+--doubledef option 
+
+This a dictionary file for the vector measure. It contains the 
 'definitons' of a concept which could be used in the relatedness computation. 
 When this option is defined, for each unique word in the definition, it uses the word's 
-definition in the doubledef file. For example, the original defintion for 'cat' is, 
+definition in the doubledef file. 
 
-cat: a feline pet, feline 
+    For example, the original defintion for 'cat' is, 
+    cat: a feline pet, feline 
 
-And then, the word vector for feline and pet in the doubledef file is: 
-feline: small to medium-sized cats, cougar cheetah
-pet: cat dog bird fish
+    And then, the word vector for feline and pet in the doubledef file is: 
+    feline: small to medium-sized cats, cougar cheetah
+    pet: cat dog bird fish
 
-The final definition for cat is to combine the original definition for cat, and 
-then add the definition for feline(only add once) and pet. 
+    The final definition for cat is to combine the original definition for cat, and 
+    then add the definition for feline(only add once) and pet. 
 
-cat: a feline pet small to medium-sized cats cougar cheetah cat dog bird fish
+    cat: a feline pet small to medium-sized cats cougar cheetah cat dog bird fish
 
-For every unique word of the final definition, the doubledef finds the vector from the 
-co-occurrence matrix of each word and build the vector for cat.  
+    For every unique word of the final definition, the doubledef finds the vector from the 
+    co-occurrence matrix of each word and build the vector for cat.  
 
 Terms in the --doubledef file use the delimiter : to seperate the terms and
 their definition. It has the same format with the dictfile. Please see the
@@ -982,26 +992,28 @@ the WordNet by glossFinder. For the extraced file, we further parse
 each senses of the same word and obtain a complete definition of the
 word.
 
---compoundfile options is a compound word list for the vector or lesk measure. 
+--compoundfile options 
+
+This is a compound word list for the vector or lesk measure. 
 It defines the compound words which are treated as one word in the definitions. 
 This must be used with the vector or lesk method. When use this option, the 
 vectorindex and vectormatrix file must be generated by the corpus which also 
 use the same compound words file. 
- 
-For example, the definition for iraq and france are: 
 
-iraq : saddam hussein
-france : jacques chirac
-  
-In the --compoundfile file, "saddam hussein" and "jacques chirac" are compounds:
+    For example, the definition for iraq and france are: 
 
-jacques_chirac
-saddam_hussein
+    iraq : saddam hussein
+    france : jacques chirac
 
-So, the compound words in the definition could be detected:
+    In the --compoundfile file, "saddam hussein" and "jacques chirac" are compounds:
 
-iraq : saddam_hussein
-france : jacques_chirac
+    jacques_chirac
+    saddam_hussein
+
+    So, the compound words in the definition could be detected:
+
+    iraq : saddam_hussein
+    france : jacques_chirac
 
 The program searches the vectors for "saddam_hussein" and "jacques_chirac" in 
 the vectorindex and vectormatrix file. The thing need to pay attention is 
@@ -1009,17 +1021,23 @@ the original text must be preprocessed by searching and replacing the compounds.
 find-compounds.pl in the Text-NSP package can help to do that. So, both the vectorindex
 and the vectormatrix files are built based on the the same compound words.  
 
---config option is configure file for the lesk or vector measure. It defines 
+--config option 
+
+This is configure file for the lesk or vector measure. It defines 
 the relationship, source and rela relationship. When compute the relatedness
 of a pair, umls-similarity.pl find the corresponding relationshps and 
 source by the config file.  
 
---stoplist option is a word list file for the vector measure. The words
+--stoplist option 
+
+This is a word list file for the vector measure. The words
 in the file should be removed from the definition. In the stop list file, 
 each word is in the regular expression format. A stop word sample file 
 is under the samples folder which is called stoplist-nsp.regex.
 
---stem option is a flag for the vector measure. If we the --stem flag
+--stem option 
+
+This is a flag for the vector measure. If we the --stem flag
 is set, the words of the definition are stemmed by the the Porter Stemming
 algorithm.  
 
